./nft-chain-test
./nft-expr_bitwise-test
./nft-expr_byteorder-test
./nft-expr_cmp-test
./nft-expr_counter-test
./nft-expr_ct-test
./nft-expr_dup-test
./nft-expr_exthdr-test
./nft-expr_fwd-test
./nft-expr_immediate-test
./nft-expr_limit-test
./nft-expr_log-test
./nft-expr_lookup-test
./nft-expr_match-test
./nft-expr_masq-test
./nft-expr_meta-test
./nft-expr_numgen-test
./nft-expr_queue-test
./nft-expr_range-test
./nft-expr_redir-test
./nft-expr_nat-test
./nft-expr_objref-test
./nft-expr_payload-test
./nft-expr_quota-test
./nft-expr_reject-test
./nft-expr_target-test
./nft-expr_hash-test
./nft-rule-test
./nft-set-test
./nft-table-test
./nft-object-test
./nft-parsing-test -d jsonfiles
